@@ -1,16 +1,15 @@
 from base64 import b64decode
 
-from django.contrib.auth.models import User
+from django.contrib.auth.models import Group, User
 from django.db import models
 
-
 class Password(models.Model):
     name = models.CharField(max_length=255)
     username = models.CharField(max_length=255, null=True, blank=True)
     domain = models.CharField(max_length=255, null=True, blank=True)
     passwd = models.CharField(max_length=255)
-    is_public = models.BooleanField('Public?')
-    user = models.ForeignKey(User, related_name='incunapassword_employee_related')
+    user = models.ForeignKey(User, related_name='user_related')
+    group = models.ManyToManyField(Group, blank=True, help_text='Deselect all groups to make password private.')
 
     class Meta:
         ordering = ('name',)
@@ -28,3 +27,11 @@ class Password(models.Model):
     def password(self):
         return b64decode(self.passwd)
 
+    def is_public(obj):
+        if obj.group.count() > 0:
+            return True
+        else:
+            return False
+    is_public.short_description = 'Public?'
+    is_public.boolean = True
+
